@extends('cms::admin.layouts.app')

@section('content')
    <div class="card card-body">
        <div class="table-responsive">
            <table class="table table-light">
                <thead>
                <tr>
                    <td colspan="5">
                        <form class="input-group" action="{{route('cms.manufactures.index')}}">
                            <input type="search" name="q" class="form-control"
                                   value="{{Request::query('q')}}"
                                   placeholder="@lang('erp::erp.search_manufacture')">
                            <div class="input-group-append">
                                <button class="btn btn-outline-success"><i class="fas fa-search"></i>
                                    <span class="d-none d-md-inline">@lang('erp::erp.search')</span></button>
                            </div>
                        </form>
                    </td>
                </tr>
                <tr>
                    <th>{{trans('erp::erp.manufacture_image') }}</th>
                    <th>@sortablelink('manufacture_name', trans('erp::erp.manufacture_name'))</th>
                    <th>{{trans('erp::erp.manufacture_url') }}</th>
                    <th>@sortablelink('products_count', trans('erp::erp.products_amount'))</th>
                    <th class="text-right">
                        <a href="{{route('cms.manufactures.create')}}" class="btn btn-outline-primary btn-sm">
                            <i class="fas fa-plus-circle"></i>
                            <span class="d-none d-md-inline">@lang('erp::erp.create_new_manufacture')</span>
                        </a>
                    </th>
                </tr>
                </thead>
                <tbody>
                <?php /** @var \TDevAgency\Erp\Models\Manufacture $manufacture */ ?>
                @forelse($manufactures as $manufacture)
                    <tr>
                        <td><img src="{{$manufacture->getImage('sm')}}" alt="" class="img-fluid"></td>
                        <td>{{$manufacture->manufacture_name}}</td>
                        <td><a href="{{$manufacture->manufacture_url}}"
                               target="_blank">{{$manufacture->manufacture_url}}</a></td>
                        <td>
                            <a href="{{route('cms.products.index', ['manufacture_id' => $manufacture->id])}}">{{$manufacture->products_count}}</a>
                        </td>
                        <td class="text-right text-nowrap">
                            <a href="{{route('cms.manufactures.edit', $manufacture->id)}}"
                               class="btn btn-outline-success btn-sm"><i class="fas fa-edit"></i>
                                <span class="d-none d-md-inline">@lang('erp::erp.edit_manufacture')</span></a>

                            <form method="post" @submit="confirmDelete" class="d-inline"
                                  action="{{route('cms.manufactures.destroy', $manufacture->id)}}">
                                @csrf
                                @method('DELETE')
                                <button class="btn btn-outline-danger btn-sm">
                                    <i class="fas fa-trash"></i>
                                    <span class="d-none d-md-inline">@lang('cms-fixed::admin.delete')</span>
                                </button>
                            </form>
                        </td>
                    </tr>
                @empty
                    <tr>
                        <td class="text-muted text-center" colspan="4">@lang('cms-fixed::admin.no_data')</td>
                    </tr>
                @endforelse
                </tbody>
                <tfoot>
                <tr>
                    <td colspan="4"> {!! $manufactures->appends(Request::except('page'))->render() !!}</td>
                    <td class="text-right text-nowrap">
                        <a href="{{route('cms.manufactures.create')}}" class="btn btn-outline-primary btn-sm">
                            <i class="fas fa-plus-circle"></i>
                            <span class="d-none d-md-inline">@lang('erp::erp.create_new_manufacture')</span>
                        </a>
                    </td>
                </tr>
                </tfoot>

            </table>
        </div>
    </div>
@endsection

@push('styles')
    <style>
    .img-fluid {
        max-width: 120px;
        max-height: 48px;
    }
    </style>
@endpush
