<?php

namespace TDevAgency\Erp\Controllers;

use App\Models\Delivery;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\View;
use TDevAgency\Cms\Controllers\Controller;
use Illuminate\Http\Request;
use TDevAgency\Erp\Models\Provider;

class ProviderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function index()
    {
        $view = View::make('erp::pages.providers.index');
        $view->with('providers', Provider::container()->search()->sortable('id')->paginate(30));
        return $view;
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function create()
    {
        $view = View::make('erp::pages.providers.single');
        $view->with('provider', new Provider());
        $view->with('formRoute', route('cms.providers.store'));
        $view->with('formMethod', 'POST');
        return $view;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return RedirectResponse
     */
    public function store(Request $request)
    {
        $this->validateRequest($request);

        $provider = new Provider();

        foreach ($provider->getFillable() as $field) {
            if ($request->has($field)) {
                $provider->setAttribute($field, $request->get($field));
            }
        }
        $provider->save();

        return Redirect::route('cms.providers.index')->with('toast', [
            'title' => trans('cms::admin.toast.created'),
            'status' => 'success'
        ]);
    }

    private function validateRequest(Request $request)
    {
        $this->validate($request, [
            'name' => 'string|required',
            'contact_person' => 'nullable|string',
            'phone_one' => 'nullable|string',
            'phone_two' => 'nullable|string',
            'address' => 'nullable|string',
            'email' => 'nullable|email',
        ]);
    }

    /**
     * Display the specified resource.
     *
     * @param Provider $provider
     * @return Response
     */
    public function show(Provider $provider)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param $id
     * @return \Illuminate\Contracts\View\View
     */
    public function edit($id)
    {
        $provider = Provider::container()->findOrFail($id);
        $view = View::make('erp::pages.providers.single');
        $view->with('provider', $provider);
        $view->with('formRoute', route('cms.providers.update', $provider->id));
        $view->with('formMethod', 'PUT');
        return $view;
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param $id
     * @return RedirectResponse
     */
    public function update(Request $request, $id)
    {
        $provider = Provider::container()->findOrFail($id);
        $this->validateRequest($request);

        foreach ($provider->getFillable() as $field) {
            if ($request->has($field)) {
                $provider->setAttribute($field, $request->get($field));
            }
        }
        $provider->update();

        return Redirect::route('cms.providers.index')->with('toast', [
            'title' => trans('cms::admin.toast.updated'),
            'status' => 'success'
        ]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param $id
     * @return RedirectResponse
     */
    public function destroy($id)
    {
        $provider = Provider::container()->findOrFail($id);
        if (Delivery::where('provider_id', $provider->id)->count() > 0) {
            return Redirect::back()->with('toast', [
                'title' => trans('cms::admin.toast.not_deleted'),
                'status' => 'warning',
                'body' => trans('erp::erp.provider_has_deliveries')
            ]);
        }
    }
}
