<?php

namespace TDevAgency\Erp\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Request;
use Kyslik\ColumnSortable\Sortable;
use TDevAgency\Cms\Traits\Searchable;
use TDevAgency\Erp\Traits\Containerable;

class Order extends Model
{
    use Containerable;
    use Searchable;
    use Sortable;

    public const STATUS_NEW = 0;
    public const STATUS_INPROGRESS = 1;
    public const STATUS_ON_DELIVERY = 2;
    public const STATUS_DONE = 3;
    public const STATUS_CLOSED = 4;
    public const STATUS_REFUND = 5;

    public const STATUS_REJECT = 100;

    protected $fillable = [
        'container_id',
        'customer_id',
        'order_number',
        'order_status',
        'total_price',
        'products_price',
        'order_comment'
    ];

    protected $searcable = [
        'order_number'
    ];
    protected $sortable = [
        'order_number', 'total_price'
    ];

    public function order_customer()
    {
        return $this->hasOne(OrderCustomer::class);
    }

    public function order_items()
    {
        return $this->hasMany(OrderItem::class);
    }

    public function order_delivery()
    {
        return $this->hasOne(OrderDelivery::class);
    }

    public function order_payment()
    {
        return $this->hasOne(OrderPayment::class);
    }

    public function scopeSearch(Builder $query)
    {
        if (Request::has('q') && !empty(Request::get('q'))) {
            $query->select('orders.*')
                ->join('order_customers', 'orders.id', '=', 'order_customers.order_id')
                ->join('order_deliveries', 'orders.id', '=', 'order_deliveries.order_id')
                ->where(function (Builder $query) {
                    $query->whereRaw('orders.order_number like "%' . Request::get('q') . '%"')
                        ->orWhereRaw('order_deliveries.track_number like "%' . Request::get('q') . '%"')
                        ->orWhereRaw('order_customers.first_name like "%' . Request::get('q') . '%"')
                        ->orWhereRaw('order_customers.last_name like "%' . Request::get('q') . '%"')
                        ->orWhereRaw('order_deliveries.track_number like "%' . Request::get('q') . '%"')
                        ->orWhereRaw('STR_REPLACE("[-\s+ )(]", "", order_customers.phone_one) like "%' . str_replace(['+', ' ', '-', '(', ')'], [''], Request::get('q')) . '%"');
                });
        }

        return $query;
    }
}
